==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/sound/JukeboxSongInit.java <==
package cc.thonly.reverie_dreams.sound;

import cc.thonly.reverie_dreams.Touhou;
import java.util.LinkedList;
import java.util.List;
import net.minecraft.class_3414;
import net.minecraft.class_5321;
import net.minecraft.class_6880;
import net.minecraft.class_7924;
import net.minecraft.class_9793;

import static cc.thonly.reverie_dreams.sound.SoundEventInit.registerReference;

public class JukeboxSongInit {
    public static final List<JukeBoxEntry> ENTRIES = new LinkedList<>();
    public static final JukeBoxEntry HR01_01 = registerJukeBoxEntry("hr01_01", 233, 6);
    public static final JukeBoxEntry HR02_08 = registerJukeBoxEntry("hr02_08", 296, 6);
    public static final JukeBoxEntry HR03_01 = registerJukeBoxEntry("hr03_01", 309, 6);
    public static final JukeBoxEntry MELODIC_TASTE_NIGHTMARE_BEFORE_CROSSROADS = registerJukeBoxEntry("melodic-taste-nightmare-before-crossroads", 231, 6);
    public static final JukeBoxEntry YV_FLOWER_CLOCK_AND_DREAMS = registerJukeBoxEntry("yv_flower_clock_and_dreams", 357, 6);
    public static final JukeBoxEntry GLOWING_NEEDLES_LITTLE_PEOPLE = registerJukeBoxEntry("glowing_needles_little_people", 242, 6);
    public static final JukeBoxEntry COOKIE = registerJukeBoxEntry("cookie", 72, 6);
    public static final JukeBoxEntry BAD_APPLE = registerJukeBoxEntry("badapple", 219,6);

    private static JukeBoxEntry registerJukeBoxEntry(String id, int length, int output) {
        class_5321<class_9793> jukeboxSongRegistryKey = createJukeBoxSongRegistryKey(id);
        class_6880.class_6883<class_3414> soundEventReference = registerReference(id);
        JukeBoxEntry entry = new JukeBoxEntry(id, jukeboxSongRegistryKey, soundEventReference, length, output);
        ENTRIES.add(entry);
        return entry;
    }

    private static class_5321<class_9793> createJukeBoxSongRegistryKey(String id) {
        return class_5321.method_29179(class_7924.field_52176, Touhou.id(id));
    }

    public static void init() {

    }

}

==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/sound/JukeboxSongInit.java <==
package cc.thonly.reverie_dreams.sound;

import cc.thonly.reverie_dreams.ReverieDreams;

import java.util.LinkedList;
import java.util.List;
import net.minecraft.class_3414;
import net.minecraft.class_5321;
import net.minecraft.class_6880;
import net.minecraft.class_7924;
import net.minecraft.class_9793;

import static cc.thonly.reverie_dreams.sound.SoundEventInit.registerReference;

public class JukeboxSongInit {
    public static final List<JukeBoxEntry> ENTRIES = new LinkedList<>();
    public static final JukeBoxEntry HR01_01 = registerJukeBoxEntry("hr01_01", 233, 6);
    public static final JukeBoxEntry HR02_08 = registerJukeBoxEntry("hr02_08", 296, 6);
    public static final JukeBoxEntry HR03_01 = registerJukeBoxEntry("hr03_01", 309, 6);
    public static final JukeBoxEntry MELODIC_TASTE_NIGHTMARE_BEFORE_CROSSROADS = registerJukeBoxEntry("melodic-taste-nightmare-before-crossroads", 231, 6);
    public static final JukeBoxEntry YV_FLOWER_CLOCK_AND_DREAMS = registerJukeBoxEntry("yv_flower_clock_and_dreams", 357, 6);
    public static final JukeBoxEntry GLOWING_NEEDLES_LITTLE_PEOPLE = registerJukeBoxEntry("glowing_needles_little_people", 242, 6);
    public static final JukeBoxEntry COOKIE = registerJukeBoxEntry("cookie", 72, 6);
    public static final JukeBoxEntry BAD_APPLE = registerJukeBoxEntry("badapple", 219,6);

    private static JukeBoxEntry registerJukeBoxEntry(String id, int length, int output) {
        class_5321<class_9793> jukeboxSongRegistryKey = createJukeBoxSongRegistryKey(id);
        class_6880.class_6883<class_3414> soundEventReference = registerReference(id);
        JukeBoxEntry entry = new JukeBoxEntry(id, jukeboxSongRegistryKey, soundEventReference, length, output);
        ENTRIES.add(entry);
        return entry;
    }

    private static class_5321<class_9793> createJukeBoxSongRegistryKey(String id) {
        return class_5321.method_29179(class_7924.field_52176, ReverieDreams.id(id));
    }

    public static void init() {

    }

}
